// Copyright 2012 Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
// * Redistributions of source code must retain the above copyright
//   notice, this list of conditions and the following disclaimer.
// * Redistributions in binary form must reproduce the above copyright
//   notice, this list of conditions and the following disclaimer in the
//   documentation and/or other materials provided with the distribution.
// * Neither the name of Google Inc. nor the names of its contributors
//   may be used to endorse or promote products derived from this software
//   without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

/// \file result.h
/// Utilities to create test result files.

#if !defined(KYUA_RESULT_H)
#define KYUA_RESULT_H

#include "defs.h"
#include "error_fwd.h"


/// Enumeration of the different result types.
enum kyua_result_type_t {
    KYUA_RESULT_PASSED = 0,
    KYUA_RESULT_FAILED,
    KYUA_RESULT_BROKEN,
    KYUA_RESULT_SKIPPED,
    KYUA_RESULT_EXPECTED_FAILURE,
};


kyua_error_t kyua_result_write(const char*, const enum kyua_result_type_t);
kyua_error_t kyua_result_write_with_reason(const char*,
                                           const enum kyua_result_type_t,
                                           const char*, ...)
    KYUA_DEFS_FORMAT_PRINTF(3, 4);


#endif  // !defined(KYUA_RESULT_H)
